package com.install4j.api.beaninfo;

/**
 * Base class for form component bean infos.
 * <p>Using this class is not strictly required. In principle, you could also set values for the <tt>ATTRIBUTE_*</tt> constants in the bean descriptor
 * of an unrelated bean info class.
 */
public class FormComponentBeanInfo extends Install4JBeanInfo {

    /**
     * @see #setDefaultVisibilityScript(String)
     */
    public static final String ATTRIBUTE_DEFAULT_VISIBILITY_SCRIPT = "defaultVisibilityScript";

    /**
     * Same as {@link Install4JBeanInfo#Install4JBeanInfo(String, String, String, boolean, boolean, Integer, Class, Class)} with
     *  <tt>multipleInstancesSupported</tt> set to <tt>true</tt> and <tt>installedFilesRequired</tt> set to <tt>false</tt>.
     */
    public FormComponentBeanInfo(String displayName, String shortDescription, String category, Integer sortKey, Class beanClass, Class customizerClass) {
        super(displayName, shortDescription, category, true, false, sortKey, beanClass, customizerClass);
    }

    /**
     * Same as {@link #FormComponentBeanInfo(String, String, String, Integer, Class, Class)} with a customizer class of <tt>null</tt>.
     */
    public FormComponentBeanInfo(String displayName, String shortDescription, String category, Integer sortKey, Class beanClass) {
        super(displayName, shortDescription, category, true, false, sortKey, beanClass);
    }

    /**
     * Configures the default value for the "Visibility script" property of the form component.
     * @param defaultVisibilityScript the default value
     * @see #ATTRIBUTE_DEFAULT_VISIBILITY_SCRIPT
     */
    public void setDefaultVisibilityScript(String defaultVisibilityScript) {
        getBeanDescriptor().setValue(ATTRIBUTE_DEFAULT_VISIBILITY_SCRIPT, defaultVisibilityScript);
    }

}
