package com.install4j.api.context;

/**
 * The user notification interface during unattended installations. By default, no
 * progress information is shown during unattended installations. For each installer application, you can set the
 * "Progress interface creation" script property in order to provide your own means of displaying progress information.
 * For example, you might want to go to full-screen mode during update installers on dedicated special-purpose computers.
 * <p>
 * This class adds a few methods to the default {@link ProgressInterface ProgressInterface} interface that are only
 * relevant in unattended mode.
 *
 * @author ej-technologies GmbH
 * @see ProgressInterface
 * @see Context#getProgressInterface()
 */
public interface UnattendedProgressInterface extends ProgressInterface {
    /**
     * Called when the progress interface is created and destroyed.
     * At startup, this method is called with a parameter of <tt>true</tt>, at exit it is called with a
     * parameter of <tt>false</tt>. You should use this method for the lif-cycle of a window or similar resources.
     * @param visible <tt>true</tt> at startup and <tt>false</tt> at exit
     */
    void setVisible(boolean visible);

    /**
     * Called if the cancel button is enabled or disabled.
     * @param enabled <tt>true</tt> or <tt>false</tt>
     * @see WizardContext#setCancelButtonEnabled(boolean)
     */
    void setCancelButtonEnabled(boolean enabled);

    /**
     * Called if the cancel button is made visible or invisible.
     * @param visible <tt>true</tt> or <tt>false</tt>
     * @see WizardContext#setCancelButtonVisible(boolean)
     */
    void setCancelButtonVisible(boolean visible);

    /**
     * Called if no internet connection is available for a download.
     * @return <tt>true</tt> if a GUI dialog should be displayed that asks the user for proxy information
     * or <tt>false</tt> if the download should fail.
     */
    boolean isAskForProxy();
}
